@@ -213,6 +213,10 @@ class WebProcessor(BaseProcessor):
     def request_factory(self):
         return self._request_factory
 
+    @property
+    def retry_dns_error(self):
+        return self._retry_dns_error
+
     @property
     def retry_connrefused(self):
         return self._retry_connrefused
